@@ -359,6 +359,14 @@ impl Kubectl {
         Ok(())
     }
 
+    pub(crate) async fn get_statehub_cluster_name_and_namespace(
+        &self,
+    ) -> anyhow::Result<(String, String)> {
+        self.check_statehub_cluster_object()
+            .await
+            .map(|cluster| (cluster.name(), cluster.spec.namespace))
+    }
+
     pub(crate) async fn cleanup_statehub_cluster(&self) -> anyhow::Result<()> {
         self.delete_statehub_cluster_crd().await?;
         log::debug!("Deleted StatehubCluster CRD");
