@@ -211,8 +211,10 @@ enum Command {
     UnregisterCluster {
         #[structopt(help = "Skip confirmation", long, short)]
         force: bool,
+
         #[structopt(help = "Cluster name")]
         name: v0::ClusterName,
+
         #[structopt(
             help = "Kubeconfig context to use for unregistering cluster",
             long,
@@ -220,6 +222,15 @@ enum Command {
             visible_alias = "ctx"
         )]
         context: Option<String>,
+
+        #[structopt(
+            help = "Non-interactive cluster registration, automatic defaults apply",
+            long,
+            short = "y",
+            alias = "yes",
+            hidden = true
+        )]
+        non_interactive: bool,
     },
 
     #[structopt(
@@ -722,13 +733,16 @@ impl Cli {
                 force,
                 name,
                 context,
+                non_interactive,
             } => {
                 let names = vec![name];
                 let contexts = context.into_iter().collect();
                 let kubectls = k8s::Kubectl::with_names_and_contexts(names, contexts)?;
                 let helm = k8s::Helm::skip();
 
-                statehub.unregister_cluster(kubectls, helm, force).await
+                statehub
+                    .unregister_cluster(kubectls, helm, force, non_interactive)
+                    .await
             }
             Command::UpdateCluster {
                 name,
@@ -1080,8 +1094,9 @@ impl StateHub {
         kubectls: Vec<k8s::Kubectl>,
         helm: k8s::Helm,
         force: bool,
+        non_interactive: bool,
     ) -> anyhow::Result<()> {
-        if force || self.confirm("Are you sure?") {
+        if force || non_interactive || self.confirm("Are you sure?") {
             log::info!("Make sure all the pods using statehub are terminated");
             log::info!("Uninstall helm");
             for kubectl in kubectls {
